@@ -7,12 +7,10 @@ from MyNotify import MyNotify
 
 from QNMDBusClient import QNMDBusClient
 
-import mydb
-
 
 class DialogRecordManagerExt(Ui_DialogRecordManager, QtCore.QObject):
 	stateRecordChange = QtCore.Signal()
-	def __init__(self, dlg, mydbus):
+	def __init__(self, dlg, mydb, mydbus):
 		QtCore.QObject.__init__(self)
 		self.dlg = dlg
 		self.setupUi(dlg)
@@ -20,7 +18,7 @@ class DialogRecordManagerExt(Ui_DialogRecordManager, QtCore.QObject):
 		self.mydbus = mydbus
 		self.noti = MyNotify()
 
-		self.my_db = mydb.MyDB()
+		self.my_db = mydb
 		self.listSupportIface = self.my_db.optGetSupportIface()
 
 		self.action()
